@@ -21,6 +21,7 @@ from .upload.boilerplate import upload_boilerplate
 from .utils import (
     Map,
     clean_table_cell,
+    echo_environment_variables_as_txt,
     echo_large_content,
     get_cp_url,
     get_git_checked_branch,
@@ -194,7 +195,7 @@ def app():
     "--pager/--no-pager",
     default=False,
     is_flag=True,
-    help="Choose whether to display content via pager or not.",
+    help="Choose whether to display content via pager.",
 )
 @click.option("--json", "as_json", is_flag=True, default=False)
 @click.pass_obj
@@ -390,14 +391,14 @@ def application_update(obj, strict):
     "--pager/--no-pager",
     default=False,
     is_flag=True,
-    help="Choose whether to display content via pager or not.",
+    help="Choose whether to display content via pager.",
 )
 @click.option(
     "--json",
     "as_json",
     is_flag=True,
     default=False,
-    help="Choose whether to display content in json format or not.",
+    help="Choose whether to display content in json format.",
 )
 @click.pass_obj
 @allow_remote_id_override
@@ -432,7 +433,7 @@ def deployments(obj, remote_id, pager, as_json):
     help="Select an environment (by name) from which deployments will be retrieved.",
 )
 @click.option(
-    "--all",
+    "--all-envs",
     "--all-environments",
     "all_environments",
     default=False,
@@ -444,7 +445,6 @@ def deployments(obj, remote_id, pager, as_json):
     "--limit-results",
     "limit_results",
     type=int,
-    default=50,
     help="The maximum number of results that can be retrieved.",
 )
 @click.pass_obj
@@ -454,7 +454,7 @@ def list_deployments(obj, environment, all_environments, limit_results):
     deployments across all environments of an application.
     """
 
-    results = obj.client.list_deployments(
+    results, messages = obj.client.list_deployments(
         website_id=obj.remote_id,
         environment=environment,
         all_environments=all_environments,
@@ -466,18 +466,21 @@ def list_deployments(obj, environment, all_environments, limit_results):
         echo_large_content(json_content, ctx=obj)
     else:
         content = ""
-        for env in results:
-            env_slug = env["environment"]
-            env_uuid = env["environment_uuid"]
-            content_table_title = f"Environment: {env_slug} ({env_uuid})"
+        for result in results:
+            content_table_title = f"Environment: {result['environment']} ({result['environment_uuid']})"
             columns = obj.table_format_columns
             rows = [
-                [row[key] for key in columns] for row in env["deployments"]
+                [row[key] for key in columns] for row in result["deployments"]
             ]
             content_table = table(rows, columns, tablefmt="grid")
             content += f"{content_table_title}\n{content_table}\n\n"
         echo_large_content(content.strip("\n"), ctx=obj)
 
+    if messages:
+        click.echo()
+        for msg in messages:
+            click.secho(msg, fg="yellow")
+
 
 @deployments.command(name="get")
 @click.argument("deployment_uuid")
@@ -499,7 +502,7 @@ def get_deployment(obj, deployment_uuid):
         )
         # Flipped table.
         columns = obj.table_format_columns + ["environment_variables"]
-        rows = [[key, deployment[key]] for key in columns]
+        rows = [[key, deployment[key] or ""] for key in columns]
         content_table = table(
             rows, headers=(), tablefmt="grid", maxcolwidths=50
         )
@@ -550,23 +553,31 @@ def get_deployment_environment_variable(obj, deployment_uuid, variable_name):
     "--pager/--no-pager",
     default=False,
     is_flag=True,
-    help="Choose whether to display content via pager or not.",
+    help="Choose whether to display content via pager.",
 )
 @click.option(
     "--json",
     "as_json",
     is_flag=True,
     default=False,
-    help="Choose whether to display content in json format or not.",
+    help="Choose whether to display content in json format.",
+)
+@click.option(
+    "--txt",
+    "as_txt",
+    is_flag=True,
+    default=False,
+    help="Choose whether to display content in a simple txt-like format (names and values only).",
 )
 @click.pass_obj
 @allow_remote_id_override
-def environment_variables(obj, remote_id, pager, as_json):
+def environment_variables(obj, remote_id, pager, as_json, as_txt):
     """Retrieve environment variables."""
 
     obj.remote_id = remote_id
     obj.pager = pager
     obj.as_json = as_json
+    obj.as_txt = as_txt
 
     # Environment variables in table format display less content than in
     # json format. Here are the desired columns to be displayed.
@@ -585,7 +596,7 @@ def environment_variables(obj, remote_id, pager, as_json):
     help="Select an environment (by name) from which environment variables will be retrieved.",
 )
 @click.option(
-    "--all",
+    "--all-envs",
     "--all-environments",
     "all_environments",
     default=False,
@@ -597,7 +608,6 @@ def environment_variables(obj, remote_id, pager, as_json):
     "--limit-results",
     "limit_results",
     type=int,
-    default=50,
     help="The maximum number of results that can be retrieved.",
 )
 @click.pass_obj
@@ -609,7 +619,7 @@ def list_environment_variables(
     or environment variables across all environments of an application.
     """
 
-    results = obj.client.list_environment_variables(
+    results, messages = obj.client.list_environment_variables(
         website_id=obj.remote_id,
         environment=environment,
         all_environments=all_environments,
@@ -624,12 +634,14 @@ def list_environment_variables(
     if obj.as_json:
         json_content = json.dumps(results, indent=2)
         echo_large_content(json_content, ctx=obj)
+    elif obj.as_txt:
+        echo_environment_variables_as_txt(
+            results, obj, all_environments, environment
+        )
     else:
         content = ""
         for result in results:
-            env_slug = result["environment"]
-            env_uuid = result["environment_uuid"]
-            content_table_title = f"Environment: {env_slug} ({env_uuid})"
+            content_table_title = f"Environment: {result['environment']} ({result['environment_uuid']})"
             columns = obj.table_format_columns
             rows = [
                 [clean_table_cell(row, key) for key in columns]
@@ -642,6 +654,11 @@ def list_environment_variables(
 
         echo_large_content(content.strip("\n"), ctx=obj)
 
+    if messages:
+        click.echo()
+        for msg in messages:
+            click.secho(msg, fg="yellow")
+
 
 @environment_variables.command("get")
 @click.option(
@@ -655,7 +672,7 @@ def list_environment_variables(
     help="Select an environment (by name) from which the environment variable will be retrieved.",
 )
 @click.option(
-    "--all",
+    "--all-envs",
     "--all-environments",
     "all_environments",
     default=False,
@@ -667,7 +684,6 @@ def list_environment_variables(
     "--limit-results",
     "limit_results",
     type=int,
-    default=50,
     help="The maximum number of results that can be retrieved.",
 )
 @click.argument("variable_name")
@@ -680,7 +696,7 @@ def get_environment_variable(
     or any occurrence of it across all environments of an application.
     """
 
-    results = obj.client.list_environment_variables(
+    results, messages = obj.client.list_environment_variables(
         website_id=obj.remote_id,
         environment=environment,
         all_environments=all_environments,
@@ -691,20 +707,19 @@ def get_environment_variable(
     if results:
         if obj.as_json:
             echo_large_content(json.dumps(results, indent=2), ctx=obj)
+        elif obj.as_txt:
+            echo_environment_variables_as_txt(
+                results, obj, all_environments, environment, variable_name
+            )
         else:
             content = ""
-            for env in results:
+            for result in results:
                 # Each environment will only include one environment variable
                 # because of the name filter applied previously in the request.
-                environment_variable = env["environment_variables"][0]
-                content_table_title = f"Environment: {env['environment']} ({env['environment_uuid']})"
+                env_var = result["environment_variables"][0]
+                content_table_title = f"Environment: {result['environment']} ({result['environment_uuid']})"
                 columns = obj.table_format_columns
-                row = [
-                    [
-                        clean_table_cell(environment_variable, key)
-                        for key in columns
-                    ]
-                ]
+                row = [[clean_table_cell(env_var, key) for key in columns]]
 
                 content_table = table(
                     row, columns, tablefmt="grid", maxcolwidths=50
@@ -719,6 +734,11 @@ def get_environment_variable(
             fg="yellow",
         )
 
+    if messages:
+        click.echo()
+        for msg in messages:
+            click.secho(msg, fg="yellow")
+
 
 @app.command(name="status")
 def app_status():
