@@ -48,7 +48,11 @@ def get_project_settings(path=None, silent=False):
     except (TypeError, OSError):
         raise click.ClickException(DOT_ALDRYN_FILE_NOT_FOUND)
     except json.decoder.JSONDecodeError:
-        click.secho("Error: Unexpected value in {}".format(path), fg="red")
+        click.secho(
+            "Error: Unexpected value in {}".format(path),
+            fg="red",
+            err=True,
+        )
         sys.exit(1)
 
 
@@ -141,7 +145,9 @@ def ensure_windows_docker_compose_file_exists(path):
     if not os.path.isfile(unix_path):
         # TODO: use correct exit from click
         click.secho(
-            "docker-compose.yml not found at {}".format(unix_path), fg="red"
+            "docker-compose.yml not found at {}".format(unix_path),
+            fg="red",
+            err=True,
         )
         sys.exit(1)
 
@@ -276,13 +282,32 @@ def allow_remote_id_override(func):
     """Adds an identifier option to the command, and gets the proper id"""
 
     @functools.wraps(func)
-    def read_remote_id(remote_id, *args, **kwargs):
+    def read_remote_id(obj, remote_id, *args, **kwargs):
+
         ERROR_MSG = (
             "This command requires a Divio Cloud Project id. Please "
             "provide one with the --remote-id option or call the "
             "command from a project directory."
         )
 
+        if remote_id and not remote_id.isdigit():
+            # If it's not a digit, its probably a UUID. Try to retrieve a ID from the UUID.
+
+            # We are not exposing the ID at all in v3. Also not in legacy.
+            # So, we have to
+            # * get the slug in v3
+            # * use the slug to get the ID in v1.
+
+            try:
+                slug = obj.client.get_application(application_uuid=remote_id)[
+                    "slug"
+                ]
+                remote_id = obj.client.get_website_id_for_slug(slug=slug)
+            except Exception:
+                raise click.ClickException(
+                    "Unable to retrieve application via UUID."
+                )
+
         if not remote_id:
             try:
                 remote_id = get_project_settings(silent=True)["id"]
@@ -291,14 +316,14 @@ def allow_remote_id_override(func):
             else:
                 if not remote_id:
                     raise click.ClickException(ERROR_MSG)
-        return func(remote_id, *args, **kwargs)
+        return func(obj, int(remote_id), *args, **kwargs)
 
     return click.option(
         "--remote-id",
         "remote_id",
         default=None,
-        type=int,
-        help="Remote Project ID to use for project commands. "
+        type=str,
+        help="Remote Project ID or UUID to use for project commands. "
         "Defaults to the project in the current directory using the "
         "configuration file.",
     )(read_remote_id)
@@ -317,6 +342,7 @@ def get_service_type(identifier, path=None):
         click.secho(
             "Warning: docker-compose.yml does not exist. Can not get the service type without!",
             fg="red",
+            err=True,
         )
         sys.exit(1)
     docker_compose_config = DockerComposeConfig(docker_compose)
@@ -349,6 +375,7 @@ def get_db_type(prefix, path=None):
             click.secho(
                 "Warning: docker-compose.yml does not exist. Can not get the service type without!",
                 fg="red",
+                err=True,
             )
             sys.exit(1)
         docker_compose_config = DockerComposeConfig(docker_compose)
@@ -360,6 +387,7 @@ def get_db_type(prefix, path=None):
                 "from the host to the /app directory of the container."
                 "\n\nSee https://docs.divio.com/en/latest/reference/docker-docker-compose/#database-default",
                 fg="red",
+                err=True,
             )
             sys.exit(1)
         else:
