@@ -376,7 +376,7 @@ def echo_large_content(content, ctx):
 def json_response_request_paginate(
     request, session, limit_results, params={}, url_kwargs={}
 ):
-    if limit_results < 1:
+    if limit_results is not None and limit_results < 1:
         click.secho(
             (
                 "The maximum number of results cannot be lower than 1. "
@@ -392,18 +392,24 @@ def json_response_request_paginate(
         response = request(session, params=params, url_kwargs=url_kwargs)()
         count_total_results = response["count"]
         results = []
+        messages = []
         while True:
             results += response["results"]
             next_page = response.get("next")
-            if not next_page or len(results) >= limit_results:
+
+            if not limit_results and not next_page:
+                break
+
+            if limit_results and (
+                not next_page or len(results) >= limit_results
+            ):
                 if limit_results < count_total_results:
-                    click.secho(
+                    messages.append(
                         (
                             f"There were {count_total_results} results available, "
                             f"but the limit is currently set at {limit_results}. "
-                            "Adjust the --limit option for more.\n"
-                        ),
-                        fg="yellow",
+                            "Adjust the --limit option for more."
+                        )
                     )
                 break
             response = request(
@@ -414,7 +420,7 @@ def json_response_request_paginate(
         click.secho("Error establishing connection.", fg="red", err=True)
         sys.exit(1)
 
-    return results
+    return results, messages
 
 
 def clean_table_cell(d: dict, key: str):
@@ -435,3 +441,49 @@ def clean_table_cell(d: dict, key: str):
     if v == "False":
         return False
     return v
+
+
+def echo_environment_variables_as_txt(
+    results, ctx, all_environments, environment, variable_name=None
+):
+    content = ""
+    for result in results:
+        result_content = []
+        for row in result["environment_variables"]:
+            if not row["is_sensitive"]:
+                result_content.append(f"{row['name']}={row['value']}\n")
+        if result_content:
+            result_title = f"Environment: {result['environment']} ({result['environment_uuid']})"
+            result_content.insert(
+                0, f"{result_title}\n{'-'*len(result_title)}\n"
+            )
+            result_content.append("\n\n")
+
+        content += "".join(result_content)
+
+    if content:
+        echo_large_content(content.strip("\n"), ctx=ctx)
+    else:
+        if variable_name:
+            click.secho(
+                (
+                    f"No environment variable named {variable_name!r} found for this application."
+                    if all_environments
+                    else f"No environment variable named {variable_name!r} found for {environment!r} environment."
+                ),
+                fg="yellow",
+            )
+        else:
+            click.secho(
+                (
+                    "No environment variables found for this application."
+                    if all_environments
+                    else f"No environment variables found for {environment!r} environment."
+                ),
+                fg="yellow",
+            )
+
+    click.secho(
+        "\nSensitive environment variables are not included in this view.",
+        fg="yellow",
+    )
